Summary
Functions
Provides the digamma function.
Provides the regularized lower incomplete gamma function.
Implements the inverse of the regularized incomplete gamma function.
Provides the log gamma function.
Provides the gamma function.
Provides the non-regularized lower incomplete gamma function.
Functions
Provides the digamma function.
Examples
iex> Exboost.Math.digamma(1.5)
0.03648997397857652
Provides the regularized lower incomplete gamma function.
Examples
iex> Exboost.Math.gamma_p(0.234,2.3)
0.9891753004794075
iex> Exboost.Math.gamma_p(5.0,0.0)
0.0
Implements the inverse of the regularized incomplete gamma function.
Examples:
iex> Exboost.Math.gamma_p_inv(0.234,0.9891753004794075) |> Float.round(6)
2.3
iex> Exboost.Math.gamma_p_inv(5.0,0.0)
0.0
Provides the log gamma function.
Examples
iex> Exboost.Math.lgamma(2.0)
0.0
Provides the gamma function.
Examples
iex> Exboost.Math.tgamma(1.5)
0.8862269254527579
iex> Exboost.Math.tgamma(3.0)
2.0
Provides the non-regularized lower incomplete gamma function.
Examples
iex> Exboost.Math.tgamma_lower(0.234,2.3)
3.846147673628932
iex> Exboost.Math.tgamma_lower(5.0,0.0)
0.0